NAME
VCS::LibCVS::Repository - A CVS Repository.
SYNOPSIS
DESCRIPTION
Represents a CVS Repository.
CLASS ROUTINES
new()
$repo = VCS::LibCVS::Repository->new($root)
- return type: VCS::LibCVS::Repository
- argument 1 type: . . .
-
The root of the repository, like this: :pserver:user@cvs.cvshome.org:/cvs
Creates a new Repository object with the specified root.
There is no check that the specified repository actually exists or is accessible.
INSTANCE ROUTINES
get_root()
$root = $repo->get_root()
Returns the root of this repository
get_version()
$CVS_version = $repo->get_version()
Returns the version of CVS running at this repository
get_ignoreChecker()
$ignoreChecker = $repo->get_ignoreChecker()
Returns an IgnoreChecker for this repository
equals()
if ($repo1->equals($repo2)) {
Returns true if this and the argument represent the same the repository.
SEE ALSO
VCS::LibCVS