NAME
VCS::LibCVS::Datum::LogMessage - A cvs log message.
SYNOPSIS
DESCRIPTION
A CVS log message for one revision. It parses a message of this format and provides access to the various parts:
revision 1.2.2.1
date: 2002/11/13 02:29:46; author: dissent; state: Exp; lines: +1 -0
branches: 1.2.2;
this is a boring commit with a shortish log message
but it does have two lines to it
SUPERCLASS
VCS::LibCVS::Datum
CLASS ROUTINES
new()
$log_m = VCS::LibCVS::Datum::LogMessage->new($text)
- return type: VCS::LibCVS::Datum::LogMessage
- argument 1 type: array ref of lines
-
Entire log message as a ref to an array of lines, including additional information in this form:
revision 1.2 date: 2002/11/13 02:29:46; author: dissent; state: Exp; lines: +1 -0 branches: 1.2.2;It is parsed on creation.
INSTANCE ROUTINES
get_revision()
$revision = $log_m->get_revision()
get_text()
$text = $log_m->get_text()
SEE ALSO
VCS::LibCVS